@@ -12,6 +12,8 @@ int main(int argc, char *argv[])
     MCAgent_t agent;
     char *str;
     int i;
+    int port=5051;
+
     MC_InitializeAgencyOptions(&options);
     
     for (i = 0; i < MC_THREAD_ALL; i++) {
@@ -20,11 +22,11 @@ int main(int argc, char *argv[])
     MC_SetThreadOff(&options, MC_THREAD_CP);  /* Turn off the command prompt */
 
     agency = MC_Initialize(
-            5051,
+            port,
             &options);
 	MC_ResetSignal(agency);
     /* Retrieve the first arriving agent */
-    /* Note: MC_MainLoopRetrieveAgent() pauses the agency: We'll need to unpause 
+    /* Note: MC_WaitRetrieveAgent() pauses the agency: We'll need to unpause 
      * it later with MC_SignalReset() */
     agent = MC_WaitRetrieveAgent(agency);
 	if (agent != NULL)
