@@ -9,10 +9,12 @@ int main(int argc, char *argv[])
   int dim, *extent;
   double *data;
   int i, j, size;
+  int port=5050;
+  int remote_port=5051;
 
   MC_InitializeAgencyOptions(&options);
-  MC_SetThreadOff(&options, MC_THREAD_CP);
-  agency = MC_Initialize(5050, &options);
+  MC_SetThreadOff(&options, MC_THREAD_CP); /* Turn off command prompt */
+  agency = MC_Initialize(port, &options);
 
   printf("MobileC Started\n");
   /* Note: The third argument of the following function may also be a
@@ -20,13 +22,19 @@ int main(int argc, char *argv[])
   MC_SendAgentMigrationMessageFile(agency,
       "test.xml",
       "localhost",
-      5051);
+      remote_port);
+
+  /* Wait for return-agent arrival signal */
   MC_WaitSignal(agency, MC_RECV_RETURN);
+
+  /* Make sure we caught the correct agent */
   agent = MC_FindAgentByName(agency, "mobagent3");
   if (agent == NULL) {
     fprintf(stderr, "Did not receive correct agent. \n");
     exit(1);
   }
+
+  /* Print relevant information */
   printf("%d tasks.\n", MC_GetAgentNumTasks(agent) );
   for (i = 0; i < MC_GetAgentNumTasks(agent); i++) {
     MC_GetAgentReturnData(
@@ -50,7 +58,11 @@ int main(int argc, char *argv[])
     free(data);
     free(extent);
   }
+
+  /* We must reset the signal that we previously caught with the 
+   * MC_WaitSignal() function with MC_ResetSignal() */
   MC_ResetSignal(agency);
+
   MC_End(agency);
   return 0;
 }
