@@ -12,10 +12,12 @@ int main(int argc, char *argv[])
   /* Init the agency */
   MCAgency_t agency;
   MCAgencyOptions_t options;
+  int port=5050;
+  int remote_port=5051;
 
   MC_InitializeAgencyOptions(&options);
-  MC_SetThreadOff(&options, MC_THREAD_CP);
-  agency = MC_Initialize(5050, &options);
+  MC_SetThreadOff(&options, MC_THREAD_CP); /* Turn off command prompt */
+  agency = MC_Initialize(port, &options);
 
   /* Note: The third argument of the following function may also be a
      valid IP address in the form of a string. i.e. 192.168.0.1 */
@@ -23,7 +25,7 @@ int main(int argc, char *argv[])
       agency,
       "test1.xml",
       "localhost",
-      5051);
+      remote_port);
   MC_End(agency);
 
   return 0;
