@@ -2,11 +2,6 @@
 #include <embedch.h>
 #include <stdio.h>
 
-struct arg_struct{
-    int a;
-    int b;
-}arg;
-
 int main(int argc, char *argv[])
 {
   MCAgency_t agency;
@@ -38,15 +33,16 @@ MC_GetAgentExecEngine() and using the Embedded Ch api to call
 the function. The second method involves using the Mobile-C
 api to call the function. Both of these methods used here produce
 identical results. */
-  arg.a = 50;
-  arg.b = 51;
-  /*interp = MC_GetAgentExecEngine(agent);
-    Ch_CallFuncByName(interp, "hello", &retval, arg); */
   MC_CallAgentFunc(
       agent,
       "hello",
       &retval,
-      &arg);
+      2, /* Num Arguments */
+      5,
+      7 );
+
   printf("Value of %d was returned.\n", retval);
+
+  MC_End(agency);
   return 0;
 }
