@@ -27,7 +27,7 @@ namespace LibMCInterop
      */
     class Program
     {
-        public static Cs2Ch.Fx d;
+        public static Cs2Ch.Fx f1;
         public static Cs2Ch.Fy f2;
 
         public static MCAgency Agency = new MCAgency();
@@ -46,6 +46,10 @@ namespace LibMCInterop
         {
             int temp;
             MCAgent agent;
+            Cs2Ch.arg_struct arg = new Cs2Ch.arg_struct();
+            arg.a = 11;
+            arg.b = 43;
+            int i = 0;
 
             // Calling a library function
             Console.WriteLine("get_inc_int(): " + Cs2Ch.get_inc_int().ToString());
@@ -57,11 +61,34 @@ namespace LibMCInterop
              * callback pointer before any agent tries to use the 
              * callback.
              */
-            d = new Cs2Ch.Fx(WriteLine);
-            Cs2Ch.SetCallBack(d);
-            Cs2Ch.callFptr("This is C# calling back to itself.");
+            f1 = new Cs2Ch.Fx(WriteLine);
+            Cs2Ch.SetFxCallBack(f1);
+            Cs2Ch.callFxCallback("This is C# calling back to itself.");
             f2 = new Cs2Ch.Fy(Func2);
-            Cs2Ch.SetFunc2CallBack(f2);
+            Cs2Ch.SetFyCallBack(f2);
+            Cs2Ch.callFyCallback(ref arg);
+
+            /* Test calling functions through cs2ch.
+             * This section shows the differences between
+             * calling functions in the library with by reference
+             * and by value arguments.
+             */
+            Cs2Ch.struct1_t s1 = Cs2Ch.NewStruct1();
+            Console.WriteLine("Created new struct1_t s1:");
+            Console.WriteLine(s1.ToString()); // Print s1
+            Cs2Ch.struct1_t embedded_s1;
+            Cs2Ch.struct2_t s2 = Cs2Ch.Func3(ref s1, out embedded_s1);
+            Console.WriteLine("Created new struct2_t s2 from s1:");
+            Console.WriteLine(s2.ToString()); // Print s2
+            Console.WriteLine("After creating s2, s1 is:");
+            Console.WriteLine(s1.ToString()); // Print s1
+            Console.WriteLine("The struct1_t embedded in the returned struct2_t is:");
+            Console.WriteLine(embedded_s1.ToString());
+            s2 = Cs2Ch.Func4(s1);
+            Console.WriteLine("Created new struct2_t s2 from s1 without ref:");
+            Console.WriteLine(s2.ToString()); // Print s2
+            Console.WriteLine("After creating s2 without ref, s1 is:");
+            Console.WriteLine(s1.ToString()); // Print s1
 
             // Starting the agency
             Console.WriteLine("Starting Mobile-C on port " +
@@ -95,11 +122,6 @@ namespace LibMCInterop
                     Console.WriteLine("CallAgentFunc() for agentfunc1() returned " +
                         temp.ToString() + ".");
 
-                    Cs2Ch.arg_struct arg = new Cs2Ch.arg_struct();
-                    arg.a = 11;
-                    arg.b = 43;
-                    int i = 0;
-
                     /* Call func2 */
                     Console.WriteLine("Attempting to call complex " +
                         "agent function agentfunc2().");
@@ -142,13 +164,12 @@ namespace LibMCInterop
                         // Marshal the return value (pointer to structure)...
                         arg = (Cs2Ch.arg_struct)Marshal.PtrToStructure(iptr, arg.GetType());
                         // And free the memory allocated by the agent.
-                        Marshal.FreeCoTaskMem(iptr);
+                        //Marshal.FreeHGlobal(iptr);
                     }
 
                     Console.WriteLine("CallAgentFunc() returned " +
                         temp.ToString() + ".");
-                    Console.WriteLine("Agent function agentfunc3() returned " +
-                        i.ToString() + ".");
+                    Console.WriteLine("Agent function agentfunc3() took argument " + i.ToString() + ".");
                     Console.WriteLine("After function call:");
                     Console.WriteLine("  arg.a = " + arg.a.ToString());
                     Console.WriteLine("  arg.b = " + arg.b.ToString());
