@@ -1,6 +1,6 @@
-/* SVN FILE INFO
- * $Revision: 220 $ : Last Committed Revision
- * $Date: 2008-07-31 17:23:45 -0700 (Thu, 31 Jul 2008) $ : Last Committed Date */
+ /* SVN FILE INFO
+ * $Revision: 230 $ : Last Committed Revision
+ * $Date: 2008-10-24 15:47:36 -0700 (Fri, 24 Oct 2008) $ : Last Committed Date */
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
                       University of California, Davis
@@ -635,7 +635,7 @@ agent_RunChScriptThread(void* ChAgent)
       );
   Ch_DeclareFunc(
       agent->agent_interp,
-      "int mc_CallAgentFunc(MCAgent_t agent, const char* funcName, void* returnVal, void* arg_struct);",
+      "int mc_CallAgentFunc(MCAgent_t agent, const char* funcName, void* returnVal,  ...);",
       (ChFuncdl_t)MC_CallAgentFunc_chdl
       );
   Ch_DeclareFunc(
@@ -781,6 +781,11 @@ agent_RunChScriptThread(void* ChAgent)
       "char *mc_RetrieveAgentCode(void* agent);",
       (ChFuncdl_t)MC_RetrieveAgentCode_chdl
       );
+  Ch_DeclareFunc(
+      agent->agent_interp,
+      "int mc_SaveData(MCAgent_t agent, char* name, int size, void* data);",
+      (ChFuncdl_t)MC_SaveData_chdl
+      );
   Ch_DeclareFunc(
       agent->agent_interp,
       "int mc_SemaphoreWait(int id);",
