@@ -1,6 +1,6 @@
 /* SVN FILE INFO
- * $Revision: 220 $ : Last Committed Revision
- * $Date: 2008-07-31 17:23:45 -0700 (Thu, 31 Jul 2008) $ : Last Committed Date */
+ * $Revision: 229 $ : Last Committed Revision
+ * $Date: 2008-10-02 16:27:19 -0700 (Thu, 02 Oct 2008) $ : Last Committed Date */
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
                       University of California, Davis
@@ -486,13 +486,37 @@ EXPORTMC extern int MC_BarrierInit(MCAgency_t attr, int id, int num_procs);
  */
 EXPORTMC extern int MC_ChInitializeOptions(MCAgency_t attr, ChOptions_t *options);
 
+
 /**
  * \brief           Calls a function defined in an agent
  *
  * \param agent     An initialized and executed MobileC agent
  * \param funcName  The name of the function to call
  * \param returnVal The agent function's return value
- * \param varg      The agent functions argument
+ * \param numArgs   The number of arguments supplied to the agent function
+ * \param ...       A variable argument list to be supplied to the
+ *                  agent function
+ *
+ * \return          0 if successful, error_code_t type on failure
+ *
+ * \section Example
+ * \include persistent_example/host.c
+ */
+EXPORTMC int
+MC_CallAgentFunc(
+    MCAgent_t agent,
+    const char* funcName,
+    void* returnVal,
+    int numArgs,
+    ...);
+
+/**
+ * \brief           Calls a function defined in an agent
+ *
+ * \param agent     An initialized and executed MobileC agent
+ * \param funcName  The name of the function to call
+ * \param returnVal The agent function's return value
+ * \param arg      The agent functions argument
  *
  * \note            The agent function must be of the form
  *                  'void* func(void* arg);'
@@ -502,13 +526,45 @@ EXPORTMC extern int MC_ChInitializeOptions(MCAgency_t attr, ChOptions_t *options
  * \section Example
  * \include persistent_example/host.c
  */
-EXPORTMC extern int MC_CallAgentFunc(
+EXPORTMC extern int MC_CallAgentFuncArg(
         MCAgent_t agent,
         const char* funcName,
         void* returnVal,
-        void* varg
+	void* arg
         );
 
+/**
+ * \brief           Calls a function defined in an agent
+ *
+ * \param agent     An initialized and executed MobileC agent
+ * \param funcName  The name of the function to call
+ * \param returnVal The agent function's return value
+ * \param ap        A variable argument list 
+ *
+ * \return          0 if successful, error_code_t type on failure
+ */
+EXPORTMC extern int MC_CallAgentFuncV(
+    MCAgent_t agent,
+    const char* funcName,
+    void* returnVal,
+    va_list ap);
+
+  /*
+    \brief          Calls a function defined in an agent
+    \param agent    A Mobile-C Agent
+    \param funcName The name of the function to call
+    \param returnVal (output) Return value from the agent function
+    \param arglist  Ch Variable Argument list to pass in
+   */
+EXPORTMC extern int MC_CallAgentFuncVar
+(
+ MCAgent_t agent,
+ const char* funcName,
+ void* returnVal,
+ ChVaList_t arglist
+ );
+					 
+
 
 /**
  * \brief           Compose a new agent dynamically without using a prewritten XML file.
