@@ -1,6 +1,6 @@
 /* SVN FILE INFO
- * $Revision: 220 $ : Last Committed Revision
- * $Date: 2008-07-31 17:23:45 -0700 (Thu, 31 Jul 2008) $ : Last Committed Date */
+ * $Revision: 230 $ : Last Committed Revision
+ * $Date: 2008-10-24 15:47:36 -0700 (Fri, 24 Oct 2008) $ : Last Committed Date */
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
                       University of California, Davis
@@ -411,24 +411,86 @@ MC_BarrierDelete(MCAgency_t attr, int id) /*{{{*/
   return barrier_queue_Delete(id, attr->mc_platform->barrier_queue);
 } /*}}}*/
 
+EXPORTMC int
+MC_CallAgentFunc(
+    MCAgent_t agent,
+    const char* funcName,
+    void* returnVal,
+    int numArgs,
+    ...)
+{
+  int return_code;
+  va_list vl;
+  va_start(vl, numArgs);
+  MUTEX_LOCK(agent->run_lock);
+  return_code = Ch_CallFuncByNamev(
+      agent->agent_interp,
+      funcName,
+      returnVal,
+      vl );
+  MUTEX_UNLOCK(agent->run_lock);
+  return return_code;
+}
+
 EXPORTMC int 
-MC_CallAgentFunc( /*{{{*/
+MC_CallAgentFuncArg( /*{{{*/
         MCAgent_t agent,
         const char* funcName,
         void* returnVal, /* FIXME: Should this be a double pointer? */
-        void* varg)
+        void* arg)
 {
     int return_code;
+
     MUTEX_LOCK(agent->run_lock); 
     return_code = Ch_CallFuncByName(
             agent->agent_interp,
             funcName,
             returnVal,
-            varg);
+            arg);
     MUTEX_UNLOCK(agent->run_lock); 
     return return_code;
 } /*}}}*/ 
 
+EXPORTMC int
+MC_CallAgentFuncV(
+    MCAgent_t agent,
+    const char* funcName,
+    void* returnVal,
+    va_list ap)
+{
+  int return_code;
+  MUTEX_LOCK(agent->run_lock);
+  return_code = Ch_CallFuncByNamev
+    (
+     agent->agent_interp,
+     funcName,
+     returnVal,
+     ap
+    );
+  MUTEX_UNLOCK(agent->run_lock);
+  return return_code;
+}
+
+EXPORTMC int
+MC_CallAgentFuncVar(
+		    MCAgent_t agent,
+		    const char* funcName,
+		    void* returnVal,
+		    ChVaList_t varg)
+{
+  int return_code;
+  MUTEX_LOCK(agent->run_lock);
+  return_code = Ch_CallFuncByNameVar
+    (
+     agent->agent_interp,
+     funcName,
+     returnVal,
+     varg
+     );
+  MUTEX_UNLOCK(agent->run_lock);
+  return return_code;
+}
+
 EXPORTMC int 
 MC_ChInitializeOptions(MCAgency_t attr, ChOptions_t *options) { /*{{{*/
     if(attr->mc_platform == NULL) {
@@ -1988,7 +2050,7 @@ MC_CallAgentFunc_chdl(void *varg) /*{{{*/
   MCAgent_t agent;
   const char* funcName;
   void* returnVal;
-  void* args;
+  ChVaList_t args;
 
   ChInterp_t interp;
   ChVaList_t ap;
@@ -2000,7 +2062,7 @@ MC_CallAgentFunc_chdl(void *varg) /*{{{*/
   returnVal = Ch_VaArg(interp, ap, void*);
   args =      Ch_VaArg(interp, ap, void*);
 
-  retval = MC_CallAgentFunc(
+  retval = MC_CallAgentFuncVar(
       agent,
       funcName,
       returnVal,
@@ -2632,6 +2694,41 @@ MC_RetrieveAgentCode_chdl(void *varg) /*{{{*/
   return retval;
 } /*}}}*/
 
+/* MC_SaveData_chdl */
+EXPORTCH int
+MC_SaveData_chdl(void* varg)
+{
+  ChInterp_t interp;
+  ChVaList_t ap;
+  interpreter_variable_data_p interp_var_data;
+  MCAgent_t agent;
+  int progress;
+  const char* name;
+  int size;
+  void* data;
+  
+  Ch_VaStart(interp, ap, varg);
+  agent = Ch_VaArg(interp, ap, MCAgent_t);
+  name = Ch_VaArg(interp, ap, char*);
+  size = Ch_VaArg(interp, ap, int);
+  data = Ch_VaArg(interp, ap, void*);
+
+  progress = agent->datastate->task_progress;
+
+  interp_var_data = interpreter_variable_data_New();
+  interp_var_data->name = strdup(name);
+  interp_var_data->size = size;
+  interp_var_data->data_type = CH_VOIDPTRTYPE;
+  interp_var_data->data = malloc(size);
+  memcpy(interp_var_data->data, data, size);
+
+  agent_variable_list_Add(
+      agent->datastate->tasks[progress]->agent_variable_list,
+      interp_var_data );
+
+  return 0;
+}
+
 /* MC_SearchForService_chdl */
 EXPORTCH int
 MC_SearchForService_chdl(void *varg) /*{{{*/
