@@ -860,9 +860,9 @@ namespace LibMC
          * \param       signals The ID number of the condition to signal.
          * \returns     The return value of the underlying MC_WaitSignal function.
          */
-        public int WaitSignal(int signals)
+        public int WaitSignal(MC_Signal_e /*int*/ signals)
         {
-            return _MC_WaitSignal(Agency, signals);
+            return _MC_WaitSignal(Agency, (int)signals);
         }
 
         /**
