@@ -1,6 +1,6 @@
 /* SVN FILE INFO
- * $Revision: 220 $ : Last Committed Revision
- * $Date: 2008-07-31 17:23:45 -0700 (Thu, 31 Jul 2008) $ : Last Committed Date */
+ * $Revision: 232 $ : Last Committed Revision
+ * $Date: 2008-11-03 11:44:57 -0800 (Mon, 03 Nov 2008) $ : Last Committed Date */
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
                       University of California, Davis
@@ -393,6 +393,19 @@ agent_xml_parse__task(agent_p agent, xml_parser_p xml_parser, int index)
         MXML_NO_DESCEND );
   }
 
+  /* 'persistent' */
+  attribute = mxmlElementGetAttr(
+      (mxml_node_t*)task_node,
+      "persistent"
+      );
+  if (attribute != NULL) {
+    agent->datastate->tasks[index]->persistent = 
+      atoi((char*)attribute);
+  } else {
+    agent->datastate->tasks[index]->persistent = 0;
+  }
+
+
   /* 'code_id' */
   attribute = mxmlElementGetAttr(
       (mxml_node_t*)task_node,
@@ -500,7 +513,8 @@ agent_xml_parse__data(agent_p agent, xml_parser_p xml_parser, int index)
   /* Attributes we need to parse:
    * O dim          - dimension of the return data
    * O name         - name of the return variable
-   * O persistent   - is the agent persistent for this task?
+   * X: O persistent   - is the agent persistent for this task?
+   *    note: persistent tag is now duplicated in the 'TASK' node. Usage in DATA is deprecated
    * O type         - return variable type
    * O return_value - return value, if not an array
    * O code_id      - ID of the code block to execute. If this
